@@ -2,8 +2,6 @@ package config
 
 import (
 	"fmt"
-	"os"
-	"strings"
 
 	"github.com/hashicorp/hcl/v2"
 	"github.com/hashicorp/hcl/v2/gohcl"
@@ -34,16 +32,6 @@ type MigrationBlock struct {
 	Remain hcl.Body `hcl:",remain"`
 }
 
-// Return a map of environment variables.
-func envVarMap() cty.Value {
-	envMap := make(map[string]cty.Value)
-	for _, env := range os.Environ() {
-		pair := strings.SplitN(env, "=", 2)
-		envMap[pair[0]] = cty.StringVal(pair[1])
-	}
-	return cty.MapVal(envMap)
-}
-
 // ParseMigrationFile parses a given source of migration file and returns a *tfmigrate.MigrationConfig.
 // Note that this method does not read a file and you should pass source of config in bytes.
 // The filename is used for error message and selecting HCL syntax (.hcl and .json).
