@@ -69,4 +69,9 @@ resource "null_resource" "qux" {}
 	if err != nil {
 		t.Fatalf("failed to run migrator plan: %s", err)
 	}
+
+	err = m.Apply(ctx)
+	if err != nil {
+		t.Fatalf("failed to run migrator apply: %s", err)
+	}
 }
